/**
 * Copyright (c) 2010 Perforce Software. All rights reserved.
 */
package com.perforce.maven.scm.provider.p4.command.remove;

import java.util.ArrayList;
import java.util.List;

import org.apache.maven.scm.ScmFile;
import org.apache.maven.scm.ScmFileStatus;

import com.perforce.maven.scm.provider.p4.command.P4Result;
import com.perforce.p4java.core.file.IFileSpec;

/**
 * This class handles the result from the Perforce delete command.
 */
public class P4RemoveResult
    extends P4Result
{

    /** The removals. */
    private List<ScmFile> removals = new ArrayList<ScmFile>();

    /**
     * @see com.perforce.maven.scm.provider.p4.command.P4Result#processMessage (java.lang.String)
     */
    @Override
    public String processMessage( String message )
    {
        return null;
    }

    /**
     * Extracts the file paths from the delete command result filespecs.
     * 
     * @param fileSpecs the file specs
     */
    public void processRemovals( List<IFileSpec> fileSpecs )
    {
        if ( fileSpecs != null )
        {
            for ( IFileSpec fileSpec : fileSpecs )
            {
                if ( fileSpec != null )
                {
                    if ( fileSpec.getDepotPath() != null )
                    {
                        removals.add( new ScmFile( fileSpec.getDepotPath().getPathString(), ScmFileStatus.DELETED ) );
                    }
                }
            }
        }
    }

    /**
     * Gets the removals.
     * 
     * @return the removals
     */
    public List<ScmFile> getRemovals()
    {
        return removals;
    }
}
